<?php
require_once __DIR__ . '/installation/database.php';

try {
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

$checkData = [
    'check_number' => '',
    'date_written' => date('Y-m-d'), 
    'payee_id' => '',
    'category_id' => '',
    'amount' => '',
    'memo_1' => '',
    'memo_2' => ''
];

if (isset($_GET['update'])) {
    $check_id = $_GET['update'];
    try {
        $stmt = $pdo->prepare("SELECT check_number, date_written, payee_id, category_id, amount, memo_1, memo_2 FROM checks WHERE check_id = ?");
        $stmt->execute([$check_id]);
        $checkData = $stmt->fetch(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        echo "<script>alert('Error fetching check data: " . $e->getMessage() . "');</script>";
    }
} else { 
    try {
        $stmt = $pdo->query("SELECT MAX(check_number) FROM checks");
        $maxCheckNumber = $stmt->fetchColumn();
        $checkData['check_number'] = $maxCheckNumber ? $maxCheckNumber + 1 : 1;
    } catch (PDOException $e) {
        echo "<script>alert('Error fetching max check number: " . $e->getMessage() . "');</script>";
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $amount = -abs($_POST['amount']);

        if (isset($_GET['update'])) {
            $stmt = $pdo->prepare("UPDATE checks SET check_number = ?, date_written = ?, payee_id = ?, category_id = ?, amount = ?, memo_1 = ?, memo_2 = ? WHERE check_id = ?");
            $stmt->execute([
                $_POST['check_number'],
                $_POST['date_written'],
                $_POST['payee_id'],
                $_POST['category_id'],
                $amount, 
                $_POST['memo_1'],
                $_POST['memo_2'],
                $_GET['update']
            ]);
            $check_id = $_GET['update'];
        } else {
            $stmt = $pdo->query("SELECT MAX(check_id) FROM checks");
            $maxId = $stmt->fetchColumn();
            $check_id = $maxId ? $maxId + 1 : 1;
            $stmt = $pdo->prepare("INSERT INTO checks (check_id, check_number, date_written, payee_id, category_id, amount, memo_1, memo_2) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([
                $check_id,
                $_POST['check_number'],
                $_POST['date_written'],
                $_POST['payee_id'],
                $_POST['category_id'],
                $amount, 
                $_POST['memo_1'],
                $_POST['memo_2']
            ]);
        }


        header("Location: " . $_SERVER['REQUEST_URI']);
        exit; 
    } catch (PDOException $e) {
        echo "<script>alert('Error: " . $e->getMessage() . "');</script>";
    }
}

try {
    $stmt = $pdo->query("SELECT category_id, category_name FROM categories");
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    echo "<script>alert('Error fetching categories: " . $e->getMessage() . "');</script>";
    $categories = [];
}

try {
    $stmt = $pdo->query("SELECT payee_id, friendly_name, category_id FROM payees");
    $payees = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    echo "<script>alert('Error fetching payees: " . $e->getMessage() . "');</script>";
    $payees = [];
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Checks Register New Debit</title>
    <link rel="stylesheet" href="./frontend-assets/css/style.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined" />
</head>
<body>
    <div class="page-container">
        <aside>
        </aside>
        <main>
            <h4><?= isset($_GET['update']) ? 'Save Changes' : 'New Debit' ?></h4>
            <div class="contain" id="check-add-div">
                <form method="post">
                    <input type="text" class="number-input" name="check_number" required placeholder="*Check Number" autocomplete="off" value="<?= htmlspecialchars($checkData['check_number']) ?>">
                    <input type="date" name="date_written" required autocomplete="off" value="<?= htmlspecialchars($checkData['date_written']) ?>">
                    <select required id="check-payee-def" name="payee_id" onchange="loadPayeeDefaults(this.value)">
                        <option disabled <?= empty($checkData['payee_id']) ? 'selected' : '' ?>>Select a Payee</option>
                        <?php foreach ($payees as $payee): ?>
                            <option value="<?= $payee['payee_id'] ?>" <?= $payee['payee_id'] == $checkData['payee_id'] ? 'selected' : '' ?>><?= htmlspecialchars($payee['friendly_name']) ?></option>
                        <?php endforeach; ?>
                    </select>
                    <select id="check-category-def" required name="category_id">
                        <option disabled <?= empty($checkData['category_id']) ? 'selected' : '' ?>>Select a Category</option>
                        <?php foreach ($categories as $category): ?>
                            <option value="<?= $category['category_id'] ?>" <?= $category['category_id'] == $checkData['category_id'] ? 'selected' : '' ?>><?= htmlspecialchars($category['category_name']) ?></option>
                        <?php endforeach; ?>
                    </select>
                    <input type="text" class="money-input" id="amount" name="amount" required placeholder="*Amount" autocomplete="off" value="<?= htmlspecialchars($checkData['amount']) ?>">
                    <input type="text" id="memo_1" name="memo_1" placeholder="Memo 1" autocomplete="off" value="<?= htmlspecialchars($checkData['memo_1']) ?>">
                    <input type="text" name="memo_2" placeholder="Memo 2" autocomplete="off" value="<?= htmlspecialchars($checkData['memo_2']) ?>">
                    <input type="submit" value="<?= isset($_GET['update']) ? 'Save Changes' : 'Save Debit' ?>">
                </form>
            </div>
        </main>
    </div>
    <script>
        async function loadMenu() {
            try {
                const response = await fetch('./frontend-assets/templates/menu.html');
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const menuHtml = await response.text();
                const asideElement = document.querySelector('aside');
                if (asideElement) {
                    asideElement.innerHTML = menuHtml;
                } else {
                    console.error("Aside element not found");
                }
            } catch (error) {
                console.error('Error loading menu:', error);
            }
        }

        async function loadPayeeDefaults(payeeId) {
            try {
                const response = await fetch(`./backend-assets/payee_defaults.php?payee_id=${payeeId}`);
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const data = await response.json();
                document.getElementById('amount').value = data.default_amt || '';
                document.getElementById('memo_1').value = data.default_memo || '';
                const payeeCategoryId = <?= json_encode(array_column($payees, 'category_id', 'payee_id')) ?>;
                document.getElementById('check-category-def').value = payeeCategoryId[payeeId] || '';

            } catch (error) {
                console.error('Error loading payee defaults:', error);
            }
        }

        loadMenu();
    </script>
    <script src="./frontend-assets/js/validation.js"></script>
</body>
</html>
