<?php
$databaseFile = './installation/database.php';

if (file_exists($databaseFile)) {
    try {
        require_once $databaseFile;
        try {
            $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        } catch (PDOException $e) {
            error_log("Database connection error: " . $e->getMessage());
            echo "Database connection failed. Check server logs.";
            exit;
        }
        function generatePayeeId($pdo) {
            try {
                do {
                    $payee_id = random_int(1, 1000000);
                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM payees WHERE payee_id = ?");
                    $stmt->execute([$payee_id]);
                    $count = $stmt->fetchColumn();
                } while ($count > 0);
                return $payee_id;
            } catch (PDOException $e) {
                error_log("Payee ID generation error: " . $e->getMessage());
                return false;
            }
        }
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $friendly_name = $_POST['friendly_name'];
            $acct_number = $_POST['acct_number'];
            $default_amt = $_POST['default_amt'];
            $default_memo = $_POST['default_memo'];
            $category_id = $_POST['category_id'];
            try {
                $payee_id = generatePayeeId($pdo);
                if ($payee_id === false) {
                    echo "Error generating Payee ID. Check server logs.";
                    exit;
                }
                $stmt = $pdo->prepare("INSERT INTO payees (payee_id, friendly_name, acct_number, default_amt, default_memo, category_id) VALUES (?, ?, ?, ?, ?, ?)");
                if (!$stmt) {
                    error_log("Prepare error: " . print_r($pdo->errorInfo(), true));
                    echo "Database prepare error. Check server logs.";
                    exit;
                }
                $result = $stmt->execute([$payee_id, $friendly_name, $acct_number, $default_amt, $default_memo, $category_id]);
                if (!$result) {
                    error_log("Execute error: " . print_r($stmt->errorInfo(), true));
                    echo "Database execute error. Check server logs.";
                    exit;
                }
                header("Location: ./payees.php");
                exit;
            } catch (PDOException $e) {
                error_log("Database error: " . $e->getMessage());
                echo "A database error occurred. Check server logs.";
            }
        }
    } catch (Throwable $e) {
        error_log("Error including database file or general error: " . $e->getMessage());
        echo "A critical error has occurred. Check server logs.";
    }
} else {
    error_log("Database file not found: " . $databaseFile);
    echo "Database file not found.";
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Checks Register Add Account</title>
    <link rel="stylesheet" href="./frontend-assets/css/style.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined" />
</head>
<body>
    <div class="page-container">
        <aside>
        </aside>
        <main class="add-payee">
            <h4>Add Account</h4>
            <p>Use this page to add an Account. Enter the information of the payee.</p>
            <div class="contain">
                <form method="post">
                    <input type="text" name="friendly_name" required placeholder="*Name" autocomplete="off">
                    <input type="text" name="acct_number" required placeholder="*Account Number" autocomplete="off">
                    <input type="text" class="money-input" name="default_amt" placeholder="Default Amount" autocomplete="off">
                    <input type="text" name="default_memo" placeholder="Default Memo" autocomplete="off">
                    
                    <select name="category_id" required>
                        <option value="" disabled selected>*Select Category</option>
                        <?php
                        try {
                            $categories_sql = "SELECT category_id, category_name FROM categories";
                            $categories_result = $pdo->query($categories_sql);
                            if ($categories_result->rowCount() > 0) {
                                while ($category_row = $categories_result->fetch(PDO::FETCH_ASSOC)) {
                                    echo "<option value='" . $category_row["category_id"] . "'>" . htmlspecialchars($category_row["category_name"]) . "</option>";
                                }
                            } else {
                                echo "<option value='' disabled>No categories found</option>";
                            }
                        } catch (PDOException $e) {
                            error_log("Error fetching categories: " . $e->getMessage());
                            echo "<option value='' disabled>Error loading categories</option>";
                        }
                        ?>
                    </select>

                    <input type="submit" value="Save Account">
                </form>
            </div>
        </main>
    </div>

    <script>
        async function loadMenu() {
            try {
                const response = await fetch('./frontend-assets/templates/menu.html');
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const menuHtml = await response.text();
                const asideElement = document.querySelector('aside');
                if (asideElement) {
                    asideElement.innerHTML = menuHtml;
                } else {
                    console.error("Aside element not found");
                }
            } catch (error) {
                console.error('Error loading menu:', error);
            }
        }
        loadMenu();
    </script>
    
    <script src="./frontend-assets/js/validation.js"></script>
</body>
</html>
