<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once __DIR__ . '/../installation/database.php'; // Corrected path

try {
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    http_response_code(500); // Set HTTP 500 status code
    echo json_encode(['error' => 'Database connection failed: ' . $e->getMessage()]);
    exit; // Stop further execution
}

if (isset($_GET['payee_id'])) {
    $payeeId = $_GET['payee_id'];
    try {
        $stmt = $pdo->prepare("SELECT default_amt, default_memo FROM payees WHERE payee_id = ?");
        $stmt->execute([$payeeId]);
        $result = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($result) {
            echo json_encode($result);
        } else {
            echo json_encode(['default_amt' => '', 'default_memo' => '']); // Payee not found, return empty values
        }

    } catch (PDOException $e) {
        http_response_code(500);
        echo json_encode(['error' => 'Error fetching payee defaults: ' . $e->getMessage()]);
    }
} else {
    http_response_code(400); // Bad Request, payee_id missing
    echo json_encode(['error' => 'Payee ID not provided.']);
}
?>