<?php

include './installation/database.php';

try {
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    error_log("Database connection successful");
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

function generateUniqueId($pdo) {
    $idLength = 5;
    $maxAttempts = 1000;

    for ($attempt = 0; $attempt < $maxAttempts; $attempt++) {
        $id = str_pad(mt_rand(0, 99999), $idLength, '0', STR_PAD_LEFT);
        try {
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM categories WHERE category_id = ?");
            $stmt->execute([$id]);
            $count = $stmt->fetchColumn();
            if ($count == 0) {
                return $id;
            }
        } catch (PDOException $e) {
            error_log("Error checking for unique ID: " . $e->getMessage());
            return false;
        }
    }
    error_log("Failed to generate a unique ID after {$maxAttempts} attempts.");
    return false;
}

if (isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['category_name'])) {
    $newCategoryName = trim($_POST['category_name']);

    if (!empty($newCategoryName)) {
        try {
            if (isset($_POST['category_id']) && is_numeric($_POST['category_id'])) {
                $categoryId = $_POST['category_id'];
                $stmt = $pdo->prepare("UPDATE categories SET category_name = ? WHERE category_id = ?");
                $stmt->execute([$newCategoryName, $categoryId]);
            } else {
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM categories WHERE category_name = ?");
                $stmt->execute([$newCategoryName]);
                $count = $stmt->fetchColumn();

                if ($count > 0) {
                    echo '<script>alert("Couldn\'t add category as the category already exists.");</script>';
                } else {
                    $pdo->beginTransaction();
                    $newCategoryId = generateUniqueId($pdo);
                    if ($newCategoryId === false) {
                        $pdo->rollBack();
                        echo '<script>alert("Failed to generate a unique Category ID.");</script>';
                    } else {
                        $stmt = $pdo->prepare("INSERT INTO categories (category_id, category_name) VALUES (?, ?)");
                        $stmt->execute([$newCategoryId, $newCategoryName]);
                        $insert_result = $stmt->rowCount();
                        error_log("Insert executed. Rows affected: " . $insert_result);
                        $pdo->commit();
                        error_log("Transaction committed.");
                    }
                }
            }
        } catch (PDOException $e) {
            $pdo->rollBack();
            error_log("Transaction rolled back: " . $e->getMessage());
            echo '<script>alert("Database error: ' . $e->getMessage() . '");</script>';
        }
    }
}

if (isset($_GET['delete_id']) && is_numeric($_GET['delete_id'])) {
    $deleteId = $_GET['delete_id'];
    try {
        $stmtChecks = $pdo->prepare("SELECT COUNT(*) FROM checks WHERE category_id = ?");
        $stmtChecks->execute([$deleteId]);
        $countChecks = $stmtChecks->fetchColumn();

        $stmtPayees = $pdo->prepare("SELECT COUNT(*) FROM payees WHERE category_id = ?");
        $stmtPayees->execute([$deleteId]);
        $countPayees = $stmtPayees->fetchColumn();

        if ($countChecks > 0 || $countPayees > 0) {
            echo '<script>alert("You can\'t delete that category as it is in use. Recategorize checks and payees to ensure it is not being used before deleting.");</script>';
        } else {
            $stmt = $pdo->prepare("DELETE FROM categories WHERE category_id = ?");
            $stmt->execute([$deleteId]);
        }
    } catch (PDOException $e) {
        echo '<script>alert("Database error: ' . $e->getMessage() . '");</script>';
    }
}

try {
    $stmt = $pdo->query("SELECT category_id, category_name FROM categories ORDER BY category_name");
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("Database error: " . $e->getMessage());
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Checks Register Categories</title>
    <link rel="stylesheet" href="./frontend-assets/css/style.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined" />
    <script>
        function editCategory(categoryId, categoryName, tdElement) {
            tdElement.innerHTML = `<input type="text" name="category_name" value="${categoryName}"><input type="hidden" name="category_id" value="${categoryId}">`;
        }
    </script>
</head>
<body>
    <div class="page-container">
        <aside></aside>
        <main>
            <h4>Categories</h4>
            <p>You can use this page to create or edit existing categories. To create a new category, type the category name on the top dotted line and click Save at the bottom.</p>
            <div class="contain">
                <form method="post">
                    <table>
                        <tbody>
                            <th>Category Name</th>
                            <tr>
                                <td><input type="text" autocomplete="off" name="category_name"></td>
                            </tr>
                            <?php foreach ($categories as $category): ?>
                            <tr>
                                <td id="cat-<?php echo $category['category_id']; ?>">
                                    <span class="material-symbols-outlined" onclick="location.href='?delete_id=<?php echo $category['category_id']; ?>'">delete</span>
                                    <span onclick="editCategory(<?php echo $category['category_id']; ?>, '<?php echo htmlspecialchars($category['category_name']); ?>', this.parentElement)"><?php echo htmlspecialchars($category['category_name']); ?></span>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                            <tr>
                                <td><input type="submit" value="Save"></td>
                            </tr>
                        </tbody>
                    </table>
                </form>
            </div>
        </main>
    </div>
    <script>
        async function loadMenu() {
            try {
                const response = await fetch('./frontend-assets/templates/menu.html');
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const menuHtml = await response.text();
                const asideElement = document.querySelector('aside');
                if (asideElement) {
                    asideElement.innerHTML = menuHtml;
                } else {
                    console.error("Aside element not found");
                }
            } catch (error) {
                console.error('Error loading menu:', error);
            }
        }
        loadMenu();
    </script>
</body>
</html>