<?php
require_once __DIR__ . '/installation/database.php';
date_default_timezone_set('UTC');

try {
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

try {
    $stmt = $pdo->query("SELECT category_id, category_name FROM categories");
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    echo "<script>alert('Error fetching categories: " . $e->getMessage() . "');</script>";
    $categories = [];
}

try {
    $stmt = $pdo->query("SELECT payee_id, friendly_name FROM payees");
    $payees = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    echo "<script>alert('Error fetching payees: " . $e->getMessage() . "');</script>";
    $payees = [];
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $params = [];
    if (!empty($_POST['from-date'])) {
        $params['from'] = $_POST['from-date'];
    }
    if (!empty($_POST['to-date'])) {
        $params['to'] = $_POST['to-date'];
    }
    if (!empty($_POST['payee_id'])) {
        $params['payee'] = $_POST['payee_id'];
    }
    if (!empty($_POST['category_id'])) {
        $params['category'] = $_POST['category_id'];
    }
    if (!empty($_POST['lowest-amt'])) {
        $params['amtlow'] = $_POST['lowest-amt'];
    }
    if (!empty($_POST['highest-amt'])) {
        $params['amthigh'] = $_POST['highest-amt'];
    }
    if (isset($_POST['exclude_deposits'])) {
        $params['exclude_deposits'] = 'true';
    }
    if (isset($_POST['exclude_checks'])) {
        $params['exclude_checks'] = 'true';
    }

    $url = './checks.php?search=true';
    foreach ($params as $key => $value) {
        $url .= '&' . urlencode($key) . '=' . urlencode($value);
    }

    header('Location: ' . $url);
    exit;
}

$searchResults = [];
$totalAmount = 0;
$totalCredits = 0;
$totalDebits = 0;
$hasResults = false;
if (isset($_GET['search']) && $_GET['search'] === 'true') {
    $sql = "SELECT checks.check_id, checks.check_number, checks.date_written, checks.amount, checks.memo_1, checks.times_printed, payees.friendly_name as payee_name, categories.category_name as category_name FROM checks LEFT JOIN payees ON checks.payee_id = payees.payee_id LEFT JOIN categories ON checks.category_id = categories.category_id WHERE 1";

    $conditions = [];
    $values = [];

    if (isset($_GET['from'])) {
        $from_date = DateTime::createFromFormat('Y-m-d', $_GET['from']);
        if ($from_date) {
            $conditions[] = "DATE(checks.date_written) >= ?";
            $values[] = $from_date->format('Y-m-d');
        } else {
            echo "<script>alert('Invalid from date format. Please useтпункт-MM-DD.');</script>";
        }
    }
    if (isset($_GET['to'])) {
        $to_date = DateTime::createFromFormat('Y-m-d', $_GET['to']);
        if ($to_date) {
            $conditions[] = "DATE(checks.date_written) <= ?";
            $values[] = $to_date->format('Y-m-d');
        } else {
            echo "<script>alert('Invalid to date format. Please useтпункт-MM-DD.');</script>";
        }
    }
    if (isset($_GET['payee'])) {
        $conditions[] = "checks.payee_id = ?";
        $values[] = $_GET['payee'];
    }
    if (isset($_GET['category'])) {
        $conditions[] = "checks.category_id = ?";
        $values[] = $_GET['category'];
    }
    if (isset($_GET['amtlow'])) {
        $conditions[] = "checks.amount >= ?";
        $values[] = $_GET['amtlow'];
    }
    if (isset($_GET['amthigh'])) {
        $conditions[] = "checks.amount <= ?";
        $values[] = $_GET['amthigh'];
    }
    if (isset($_GET['exclude_deposits']) && $_GET['exclude_deposits'] === 'true') {
        $conditions[] = "checks.amount < 0"; 
    }
    if (isset($_GET['exclude_checks']) && $_GET['exclude_checks'] === 'true') {
        $conditions[] = "checks.amount > 0"; 
    }

    if (!empty($conditions)) {
        $sql .= " AND " . implode(" AND ", $conditions);
    }

    $sort_field = isset($_GET['sort']) ? $_GET['sort'] : 'checks.date_written';
    $sort_order = isset($_GET['order']) ? $_GET['order'] : 'DESC'; 

    $allowed_fields = ['checks.check_number', 'category_name', 'checks.date_written', 'payee_name', 'checks.amount', 'checks.memo_1', 'checks.times_printed'];
    if (!in_array($sort_field, $allowed_fields)) {
        $sort_field = 'checks.date_written';
    }

    $sort_order = strtoupper($sort_order);
    if ($sort_order != 'ASC' && $sort_order != 'DESC') {
        $sort_order = 'DESC'; 
    }

    $sql .= " ORDER BY " . $sort_field . " " . $sort_order;

    try {
        $stmt = $pdo->prepare($sql);
        $stmt->execute($values);
        $searchResults = $stmt->fetchAll(PDO::FETCH_ASSOC);
        $hasResults = count($searchResults) > 0;
        foreach ($searchResults as $result) {
            $amount = floatval($result['amount']);
            $totalAmount += $amount;
            if ($amount >= 0) {
                $totalCredits += $amount;
            } else {
                $totalDebits += $amount;
            }
        }
    } catch (PDOException $e) {
        echo "<script>alert('Error fetching search results: " . $e->getMessage() . "');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Checks Register Main Report</title>
    <link rel="stylesheet" href="./frontend-assets/css/style.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined" />
    <style>
        .print-checkbox {
            margin: 0 auto;
            display: block;
        }
        .clickable-cell {
            cursor: pointer;
        }
        .positive-num {
            color: green;
        }
        .negative-num {
            color: red;
        }
        .sortable-header {
            cursor: pointer;
            align-items: center;
            gap: 5px;
            transition: all 0.4s;
            padding-top: 0px !important;
        }
        .sortable-header:hover {
            background-color: #2d2842;
        }
        .material-symbols-outlined {
            font-size: 16px !important;
            top: 5px;
        }
    </style>
</head>
<body>
    <div class="page-container">
        <aside>
        </aside>
        <main>
            <h4>Main Report</h4>
            <p>Use this tool to generate a main report. You can leave the search form blank to search all records.</p>
            <div class="contain" id="search-tool" style="<?php echo isset($_GET['search']) && $_GET['search'] === 'true' ? 'display:none;' : 'display:block;'; ?>">
                <form method="post">
                    <p style="margin-bottom:20px;">By date range</label><p>
                    <label for="from-date">From</label>
                    <input style="margin-bottom:20px;" type="date" name="from-date">
                    <label for="to-date">To</label>
                    <input type="date" name="to-date">
                    <hr>
                    <label>By account or category</label>
                    <select name="payee_id">
                        <option value="" selected disabled>Select an Account</option>
                        <?php foreach ($payees as $payee): ?>
                            <option value="<?= $payee['payee_id'] ?>"><?= htmlspecialchars($payee['friendly_name']) ?></option>
                        <?php endforeach; ?>
                    </select>
                    <select name="category_id">
                        <option value="" selected disabled>Select a Category</option>
                        <?php foreach ($categories as $category): ?>
                            <option value="<?= $category['category_id'] ?>"><?= htmlspecialchars($category['category_name']) ?></option>
                        <?php endforeach; ?>
                    </select>
                    <hr>
                    <label>By dollar amount</label>
                    <input type="text" class="money-input" name="lowest-amt" placeholder="Lowest Amt" autocomplete="off">
                    <input type="text" class="money-input" name="highest-amt" placeholder="Highest Amt" autocomplete="off">
                    <hr>
                    <input id="excl-credit" type="checkbox" name="exclude_deposits">
                    <label for="excl-credit">Exclude Credits</label>
                    <input id="excl-debit" type="checkbox" name="exclude_checks">
                    <label for="excl-debit">Exclude Debits</label>
                    <input type="submit" value="Search">
                </form>
            </div>
            <div class="contain" id="search-results" style="<?php echo isset($_GET['search']) && $_GET['search'] === 'true' ? 'display:block;' : 'display:none;'; ?>">
                <form id="print-form" method="get" action="./print.php">
                    <table>
                        <thead>
                            <tr>
                                <th class="sortable-header" data-field="checks.check_number">
                                    Check Number
                                    <?php if (isset($_GET['sort']) && $_GET['sort'] == 'checks.check_number'): ?>
                                        <span class="material-symbols-outlined"><?php echo $_GET['order'] == 'ASC' ? 'arrow_downward' : 'arrow_upward'; ?></span>
                                    <?php else: ?>
                                        <span class="material-symbols-outlined">unfold_more</span>
                                    <?php endif; ?>
                                </th>
                                <th class="sortable-header" data-field="category_name">
                                    Category
                                    <?php if (isset($_GET['sort']) && $_GET['sort'] == 'category_name'): ?>
                                        <span class="material-symbols-outlined"><?php echo $_GET['order'] == 'ASC' ? 'arrow_downward' : 'arrow_upward'; ?></span>
                                    <?php else: ?>
                                        <span class="material-symbols-outlined">unfold_more</span>
                                    <?php endif; ?>
                                </th>
                                <th class="sortable-header" data-field="checks.date_written">
                                    Date Written
                                    <?php if (isset($_GET['sort']) && $_GET['sort'] == 'checks.date_written'): ?>
                                        <span class="material-symbols-outlined"><?php echo $_GET['order'] == 'ASC' ? 'arrow_downward' : 'arrow_upward'; ?></span>
                                    <?php else: ?>
                                        <span class="material-symbols-outlined">unfold_more</span>
                                    <?php endif; ?>
                                </th>
                                <th class="sortable-header" data-field="payee_name">
                                    Paid To
                                    <?php if (isset($_GET['sort']) && $_GET['sort'] == 'payee_name'): ?>
                                        <span class="material-symbols-outlined"><?php echo $_GET['order'] == 'ASC' ? 'arrow_downward' : 'arrow_upward'; ?></span>
                                    <?php else: ?>
                                        <span class="material-symbols-outlined">unfold_more</span>
                                    <?php endif; ?>
                                </th>
                                <th class="sortable-header" data-field="checks.amount">
                                    Amount
                                    <?php if (isset($_GET['sort']) && $_GET['sort'] == 'checks.amount'): ?>
                                        <span class="material-symbols-outlined"><?php echo $_GET['order'] == 'ASC' ? 'arrow_downward' : 'arrow_upward'; ?></span>
                                    <?php else: ?>
                                        <span class="material-symbols-outlined">unfold_more</span>
                                    <?php endif; ?>
                                </th>
                                <th class="sortable-header" data-field="checks.memo_1">
                                    Memo 1
                                    <?php if (isset($_GET['sort']) && $_GET['sort'] == 'checks.memo_1'): ?>
                                        <span class="material-symbols-outlined"><?php echo $_GET['order'] == 'ASC' ? 'arrow_downward' : 'arrow_upward'; ?></span>
                                    <?php else: ?>
                                        <span class="material-symbols-outlined">unfold_more</span>
                                    <?php endif; ?>
                                </th>
                                <th class="sortable-header" data-field="checks.times_printed">
                                    Times Printed
                                    <?php if (isset($_GET['sort']) && $_GET['sort'] == 'checks.times_printed'): ?>
                                        <span class="material-symbols-outlined"><?php echo $_GET['order'] == 'ASC' ? 'arrow_downward' : 'arrow_upward'; ?></span>
                                    <?php else: ?>
                                        <span class="material-symbols-outlined">unfold_more</span>
                                    <?php endif; ?>
                                </th>
                                <th>Print</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            $totalAmount = 0;
                            $totalCredits = 0;
                            $totalDebits = 0;
                            if ($hasResults):
                                foreach ($searchResults as $result):
                                    $amount = floatval($result['amount']);
                                    $totalAmount += $amount;
                                    if ($amount >= 0) {
                                        $totalCredits += $amount;
                                    } else {
                                        $totalDebits += $amount;
                                    }
                                    $target_url = $amount >= 0 ? './deposit.php?update=' . $result['check_id'] : './add_check.php?update=' . $result['check_id'];
                                    ?>
                                    <tr>
                                        <td class="clickable-cell" onclick="window.location.href='<?= $target_url ?>';"><?= htmlspecialchars($result['check_number']) ?></td>
                                        <td class="clickable-cell" onclick="window.location.href='<?= $target_url ?>';"><?= htmlspecialchars($result['category_name']) ?></td>
                                        <td class="clickable-cell" onclick="window.location.href='<?= $target_url ?>';"><?= htmlspecialchars($result['date_written']) ?></td>
                                        <td class="clickable-cell" onclick="window.location.href='<?= $target_url ?>';"><?= htmlspecialchars($result['payee_name']) ?></td>
                                        <td class="clickable-cell <?php echo $amount >= 0 ? 'positive-num' : 'negative-num'; ?>" onclick="window.location.href='<?= $target_url ?>';"><?= htmlspecialchars(number_format($result['amount'], 2)) ?></td>
                                        <td class="clickable-cell" onclick="window.location.href='<?= $target_url ?>';"><?= htmlspecialchars($result['memo_1']) ?></td>
                                        <td class="clickable-cell" onclick="window.location.href='<?= $target_url ?>';"><?= htmlspecialchars($result['times_printed']) ?></td>
                                        <td>
                                            <?php if ($amount < 0): ?>
                                                <input type="checkbox" class="print-checkbox" name="id[]" value="<?= $result['check_id'] ?>">
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach;
                            else: ?>
                                <tr><td colspan="8">No results found</td></tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                    <p id="results-total" class="<?php echo $totalAmount >= 0 ? 'positive-num' : 'negative-num'; ?>">Total Amount: <?= htmlspecialchars(number_format($totalAmount, 2)) ?></p>
                    <p id="credits-total" class="positive-num">Total Credits: <?= htmlspecialchars(number_format($totalCredits, 2)) ?></p>
                    <p id="debits-total" class="negative-num">Total Debits: <?= htmlspecialchars(number_format($totalDebits, 2)) ?></p>
                    <button type="submit">Print out selection</button>
                    <button type="button" id="print-group-button">Print as group</button>
                </form>
            </div>
        </main>
    </div>
    <script>
        async function loadMenu() {
            try {
                const response = await fetch('./frontend-assets/templates/menu.html');
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const menuHtml = await response.text();
                const asideElement = document.querySelector('aside');
                if (asideElement) {
                    asideElement.innerHTML = menuHtml;
                } else {
                    console.error("Aside element not found");
                }
            } catch (error) {
                console.error('Error loading menu:', error);
            }
        }
        loadMenu();

        document.querySelectorAll('.sortable-header').forEach(header => {
            header.addEventListener('click', function() {
                const field = this.dataset.field;
                let order = 'ASC';
                if (field === getUrlParameter('sort')) {
                    order = getUrlParameter('order') === 'ASC' ? 'DESC' : 'ASC';
                }
                let url = './checks.php?search=true';
                const params = {
                    'sort': field,
                    'order': order,
                };
                const existingParams = ['from', 'to', 'payee', 'category', 'amtlow', 'amthigh', 'exclude_deposits', 'exclude_checks'];
                existingParams.forEach(param => {
                    const value = getUrlParameter(param);
                    if (value) {
                        params[param] = value;
                    }
                });
                for (const key in params) {
                    url += '&' + encodeURIComponent(key) + '=' + encodeURIComponent(params[key]);
                }
                window.location.href = url;
            });
        });

        function getUrlParameter(name) {
            name = name.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
            const regex = new RegExp("[\\?&]" + name + "=([^&#]*)"),
                results = regex.exec(location.search);
            return results === null ? "" : decodeURIComponent(results[1].replace(/\+/g, " "));
        }
        document.getElementById('print-group-button').addEventListener('click', function(){
            const checkedBoxes = document.querySelectorAll('input[name="id[]"]:checked');
            const ids = Array.from(checkedBoxes).map(box => box.value).join(',');
            if (ids) {
                window.location.href = './debit_group.php?create=' + ids;
            } else {
                alert('Please select at least one item to print as a group.');
            }
        });
        document.getElementById('print-form').addEventListener('submit', function(event) {
            event.preventDefault(); 
            const checkedBoxes = document.querySelectorAll('input[name="id[]"]:checked');
            const ids = Array.from(checkedBoxes).map(box => box.value);

            if (ids.length === 1) {
                window.location.href = './print.php?id=' + ids[0];
            } else if (ids.length > 1) {
                window.location.href = './print.php?id=' + ids.join(',');
            } else {
                alert('Please select at least one item to print.');
            }
        });
    </script>
    <script src="./frontend-assets/js/validation.js"></script>
</body>
</html>