<?php
include './installation/database.php';

try {
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    error_log("Database connection successful");
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $from_date = $_POST["fromdate-report"];
    $to_date = $_POST["todate-report"];

    if (empty($from_date) || empty($to_date)) {
        echo "Please select both 'From' and 'To' dates.";
        exit;
    }

    $from_timestamp = strtotime($from_date);
    $to_timestamp = strtotime($to_date);

    if ($from_timestamp > $to_timestamp) {
        echo "Invalid date range: 'From' date should be before 'To' date.";
        exit;
    }

    $csv_data = [];

    $stmt = $pdo->query("SELECT category_name FROM categories");
    $categories = $stmt->fetchAll(PDO::FETCH_COLUMN);

    $month_ranges = [];
    $current_month = $from_timestamp;
    while ($current_month <= $to_timestamp) {
        $month_start = date('Y-m-01', $current_month);
        $month_end = date('Y-m-t', $current_month);

        $month_start_timestamp = strtotime($month_start);
        $month_end_timestamp = strtotime($month_end);

        if (strtotime($from_date) > $month_start_timestamp && date('Y-m', $from_timestamp) == date('Y-m', $current_month)) {
            $month_start = $from_date;
        }

        if (strtotime($to_date) < $month_end_timestamp && date('Y-m', $to_timestamp) == date('Y-m', $current_month)) {
            $month_end = $to_date;
        }

        $month_ranges[] = [
            'start' => $month_start,
            'end' => $month_end,
            'label' => date('M Y', $current_month)
        ];
        $current_month = strtotime('+1 month', $current_month);
    }

    $header_row = ['Categories'];
    foreach ($month_ranges as $month_range) {
        $header_row[] = $month_range['label'];
    }
    $header_row[] = 'Entire Period';
    $csv_data[] = $header_row;

    foreach ($categories as $category) {
        $data_row = [$category];
        $total_category_amount = 0;
        foreach ($month_ranges as $month_range) {
            $stmt = $pdo->prepare("SELECT SUM(ABS(checks.amount))
                                    FROM checks
                                    JOIN categories ON checks.category_id = categories.category_id
                                    WHERE categories.category_name = ?
                                    AND checks.date_written >= ?
                                    AND checks.date_written <= ?
                                    AND checks.amount < 0"); 
            $stmt->execute([$category, $month_range['start'], $month_range['end']]);
            $amount = $stmt->fetchColumn() ?: 0; 
            $data_row[] = $amount;
            $total_category_amount += $amount;
        }
        $data_row[] = $total_category_amount;
        $csv_data[] = $data_row;
    }

    // Add "Total" row
    $total_row = ['Total'];
    foreach ($month_ranges as $month_range) {
        $stmt = $pdo->prepare("SELECT SUM(ABS(amount))
                                FROM checks
                                WHERE checks.date_written >= ?
                                AND checks.date_written <= ?
                                AND checks.amount < 0"); 
        $stmt->execute([$month_range['start'], $month_range['end']]);
        $total_month_amount = $stmt->fetchColumn() ?: 0;
        $total_row[] = $total_month_amount;
    }
    $stmt = $pdo->prepare("SELECT SUM(ABS(amount))
                            FROM checks
                            WHERE checks.date_written >= ?
                            AND checks.date_written <= ?
                            AND checks.amount < 0"); 
    $stmt->execute([$from_date, $to_date]);
    $total_all_amount = $stmt->fetchColumn() ?: 0;
    $total_row[] = $total_all_amount;
    $csv_data[] = $total_row;

    $csv_string = '';
    foreach ($csv_data as $row) {
        $csv_string .= implode(',', $row) . "\n";
    }

    $filename = $from_date . ' to ' . $to_date . ' Comprehensive View.csv';
    header('Content-Type: text/csv');
    header('Content-Disposition: attachment;filename="' . $filename . '"');
    header('Cache-Control: max-age=0');

    echo $csv_string;
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Checks Register Comprehensive Viewer</title>
    <link rel="stylesheet" href="./frontend-assets/css/style.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined" />
</head>
<body>
    <div class="page-container" id="comprehensive-gen">
        <aside>
        </aside>
        <main>
            <h4>Comprehensive View</h4>
            <p>Set a period of time to give a comprehensive view of debits by both months and the entire time specified.</p>
            <div class="contain">
                <form method="post">
                    <label for="fromdate-report">From:</label>
                    <input id="fromdate-report" type="date" name="fromdate-report">
                    <label for="todate-report">To:</label>
                    <input id="todate-report" type="date" name="todate-report">
                    <input type="submit" value="Download Comprehensive View">
                </form>
            </div>
        </main>
    </div>

    <script>
        async function loadMenu() {
            try {
                const response = await fetch('./frontend-assets/templates/menu.html');
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const menuHtml = await response.text();
                const asideElement = document.querySelector('aside');
                if (asideElement) {
                    asideElement.innerHTML = menuHtml;
                } else {
                    console.error("Aside element not found");
                }
            } catch (error) {
                console.error('Error loading menu:', error);
            }
        }

        // Call the function on page load
        loadMenu();
    </script>
</body>
</html>
