<?php
require_once __DIR__ . '/installation/database.php';

try {
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

$depositData = [
    'date_written' => date('Y-m-d'), // Default to today's date
    'amount' => '',
    'memo_1' => ''
];

if (isset($_GET['update'])) {
    $check_id = $_GET['update'];
    try {
        $stmt = $pdo->prepare("SELECT date_written, amount, memo_1 FROM checks WHERE check_id = ?");
        $stmt->execute([$check_id]);
        $depositData = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$depositData) {
             echo "<script>alert('Deposit not found with id: " . $check_id . "'); window.location.href = '" . $_SERVER['PHP_SELF'] . "';</script>";
             exit;
        }
    } catch (PDOException $e) {
        echo "<script>alert('Error fetching deposit data: " . $e->getMessage() . "'); window.location.href = '" . $_SERVER['PHP_SELF'] . "';</script>";
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $amount = abs($_POST['amount']);

        if (isset($_GET['update'])) { 
            $check_id = $_GET['update'];
            $stmt = $pdo->prepare("UPDATE checks SET date_written = ?, amount = ?, memo_1 = ? WHERE check_id = ?");
            $stmt->execute([
                $_POST['date_written'],
                $amount,
                $_POST['memo_1'],
                $check_id
            ]);
             header("Location: " . $_SERVER['PHP_SELF']);
             exit;
        } else { 
            $check_id = random_int(100000, 999999);
            $stmt = $pdo->prepare("INSERT INTO checks (check_id, date_written, amount, memo_1) VALUES (?, ?, ?, ?)");
            $stmt->execute([
                $check_id,
                $_POST['date_written'],
                $amount,
                $_POST['memo_1']
            ]);
             header("Location: " . $_SERVER['PHP_SELF']);
             exit;
        }



    } catch (PDOException $e) {
        echo "<script>alert('Error: " . $e->getMessage() . "');</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= isset($_GET['update']) ? 'Checks Register Update Credit' : 'Checks Register Add Credit' ?></title>
    <link rel="stylesheet" href="./frontend-assets/css/style.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined" />
</head>
<body>
    <div class="page-container">
        <aside>
        </aside>
        <main>
            <h4><?= isset($_GET['update']) ? 'Update Credit' : 'New Credit' ?></h4>
            <div class="contain" id="deposit-add-div">
                <form method="post">
                    <input type="date" name="date_written" required autocomplete="off" value="<?= htmlspecialchars($depositData['date_written']) ?>">
                    <input type="text" class="money-input" name="amount" required placeholder="*Amount" autocomplete="off" value="<?= htmlspecialchars($depositData['amount']) ?>">
                    <input type="text" name="memo_1" placeholder="Memo 1" autocomplete="off" value="<?= htmlspecialchars($depositData['memo_1']) ?>">
                    <input type="submit" value="<?= isset($_GET['update']) ? 'Save Changes' : 'Save Credit' ?>">
                </form>
            </div>
        </main>
    </div>
    <script>
        async function loadMenu() {
            try {
                const response = await fetch('./frontend-assets/templates/menu.html');
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const menuHtml = await response.text();
                const asideElement = document.querySelector('aside');
                if (asideElement) {
                    asideElement.innerHTML = menuHtml;
                } else {
                    console.error("Aside element not found");
                }
            } catch (error) {
                console.error('Error loading menu:', error);
            }
        }

        // Call the function on page load
        loadMenu();
    </script>
    <script src="./frontend-assets/js/validation.js"></script>
</body>
</html>
