// Existing validation functions
function validateEmail(input) {
  const emailRegex = /^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$/;
  return !emailRegex.test(input.value) ? false : true;
}

function validateRequired(input) {
  return !input.value.trim() ? false : true;
}

function validateZipCode(input) {
  const zipCodeRegex = /^\d{5}(-\d{4})?$/;
  return !zipCodeRegex.test(input.value) ? false : true;
}

function validateNumberInput(input) {
  const numberRegex = /^-?\d+(\.\d+)?$/;
  return !numberRegex.test(input.value) ? false : true;
}

// Improved money input validation
function validateMoneyInput(input) {
  let value = input.value.replace(/[^0-9.]/g, '');
  let parts = value.split('.');

  if (parts.length > 1) {
    parts = [parts[0], parts.slice(1).join('')]; //join additional decimals
    parts[1] = parts[1].substring(0, 2);
    value = parts.join('.');
  }

  input.value = value;
  return true;
}

document.addEventListener('input', function(event) {
  const target = event.target;

  if (target.classList.contains('money-input')) {
    validateMoneyInput(target);
  } else if (target.classList.contains('number-input')) {
    validateNumberInput(target);
  }
});

document.addEventListener('blur', function(event) {
  const target = event.target;
  if (target.classList.contains('money-input')) {
    let value = target.value;
    const parts = value.split('.');
    if (parts.length === 1) {
      value = value + '.00';
    } else if (parts.length === 2) {
      if (parts[1].length === 0) {
        value = value + '00';
      } else if (parts[1].length === 1) {
        value = value + '0';
      }
    }
    target.value = value;
  }
  if (target.classList.contains('email-input')) {
    validateEmail(target);
  } else if (target.classList.contains('required')) {
    validateRequired(target);
  } else if (target.classList.contains('zip-code')) {
    validateZipCode(target);
  } else if (target.classList.contains('number-input')) {
    validateNumberInput(target);
  }
});
