<?php
include 'database.php';

// Establish database connection
$conn = new mysqli($db_host, $db_user, $db_pass, $db_name);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Prepare an array to store inserted category names
$insertedCategories = [];

// Loop through POST data to find category names
foreach ($_POST as $key => $value) {
    if (strpos($key, 'category') === 0) { // Check if the key starts with 'category'
        $categoryName = trim($conn->real_escape_string($value)); // Removed strtolower()

        // Ignore blank categories
        if (empty($categoryName)) {
            continue; // Skip to the next iteration
        }

        // Check if the category name already exists (case-insensitive)
        $stmt = $conn->prepare("SELECT category_id FROM categories WHERE LOWER(category_name) = ?");
        $tempCategoryName = strtolower($categoryName);
        $stmt->bind_param("s", $tempCategoryName);
        $stmt->execute();
        $stmt->store_result();

        if ($stmt->num_rows > 0) {
            // Category name already exists, skip insertion
            $stmt->close();
            continue;
        }

        $stmt->close();

        // Get the highest current category_id and increment for the new ID
        $result = $conn->query("SELECT MAX(category_id) FROM categories");
        $row = $result->fetch_row();
        $newCategoryId = ($row[0] === null) ? 0 : $row[0] + 1;

        // Insert the category name into the database
        $stmt = $conn->prepare("INSERT INTO categories (category_id, category_name) VALUES (?, ?)");
        $stmt->bind_param("is", $newCategoryId, $categoryName); // 'i' for integer id, 's' for string name

        if ($stmt->execute()) {
            $insertedCategories[] = $categoryName;
        } else {
            echo "Error inserting category: " . $stmt->error;
        }

        $stmt->close();
    }
}

if (!empty($insertedCategories)) {
    // Categories inserted successfully, redirect to step 4
    header("Location: ./?step=4");
    exit();
} else {
    echo "No new categories inserted.";
}

$conn->close();
?>