<?php
include 'database.php';

// Establish database connection
$conn = new mysqli($db_host, $db_user, $db_pass, $db_name);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Prepare an array to store inserted payee names
$insertedPayees = [];

// Loop through POST data to find payee information
foreach ($_POST as $key => $value) {
    if (strpos($key, 'payee') === 0) { // Check if the key starts with 'payee'
        // Extract payee number and field name
        $parts = explode('_', $key);
        $payeeNumber = $parts[0];
        $fieldName = $parts[1];

        // Store payee data in an associative array
        $payeeData[$payeeNumber][$fieldName] = trim($conn->real_escape_string($value));
    }
}

// Process payee data and insert into the database
foreach ($payeeData as $payeeNumber => $data) {
    // Check if display name and account number are blank
    if (empty($data['name']) && empty($data['acctnumber'])) {
        continue; // Skip to the next iteration if both are blank
    }

    // Check if display name or account number are blank
    if (empty($data['name']) || empty($data['acctnumber'])) {
        continue; // Skip if one of the required fields is blank.
    }

    $friendlyName = $data['name'];
    $acctNumber = $data['acctnumber'];
    $defaultAmt = isset($data['defamt']) ? $data['defamt'] : ''; // Handle blank default amount
    $defaultMemo = isset($data['defmemo']) ? $data['defmemo'] : ''; // Handle blank default memo

    // Check if the payee name already exists (case-insensitive)
    $stmt = $conn->prepare("SELECT payee_id FROM payees WHERE LOWER(friendly_name) = ?");
    $tempFriendlyName = strtolower($friendlyName);
    $stmt->bind_param("s", $tempFriendlyName);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        // Payee name already exists, skip insertion
        $stmt->close();
        continue;
    }

    $stmt->close();

    // Get the highest current payee_id and increment for the new ID
    $result = $conn->query("SELECT MAX(payee_id) FROM payees");
    $row = $result->fetch_row();
    $newPayeeId = ($row[0] === null) ? 0 : $row[0] + 1;

    // Insert payee data into the database
    $stmt = $conn->prepare("INSERT INTO payees (payee_id, friendly_name, acct_number, default_amt, default_memo) VALUES (?, ?, ?, ?, ?)");
    $stmt->bind_param("sssss", $newPayeeId, $friendlyName, $acctNumber, $defaultAmt, $defaultMemo);

    if ($stmt->execute()) {
        $insertedPayees[] = $friendlyName;
    } else {
        echo "Error inserting payee: " . $stmt->error;
    }

    $stmt->close();
}

if (!empty($insertedPayees)) {
    // Payees inserted successfully, delete files
    unlink('./index.php');
    unlink('./initcategory.php');
    unlink('./initialize.php');
    unlink('./initpayee.php');

    // Redirect to /index.php
    header("Location: ../index.php");
    exit();

} else {
    echo "No new payees inserted.";
}

$conn->close();
?>