<?php
require './installation/database.php';

try {
    $conn = new mysqli($db_host, $db_user, $db_pass, $db_name);

    if (!$conn) {
        die("Connection failed: " . mysqli_connect_error());
    }

    function formatAmount($amount)
    {
        return number_format(abs($amount), 2, '.', '');
    }

    function numberToWords($num)
    {
        $f = new NumberFormatter("en", NumberFormatter::SPELLOUT);
        return ucwords($f->format(abs($num))) . ' Dollars';
    }

    $check_ids = isset($_GET['id']) ? array_map('intval', explode(',', $_GET['id'])) : [];
    $payee = isset($_GET['payee']) ? $_GET['payee'] : '';
    $amount = isset($_GET['amt']) ? floatval($_GET['amt']) : 0;
    $memo = isset($_GET['memo']) ? $_GET['memo'] : '';
    $date_str = isset($_GET['date']) ? $_GET['date'] : date('m-d-Y');
    
    $date_obj = DateTime::createFromFormat('m-d-Y', $date_str);
    if ($date_obj && $date_obj->format('m-d-Y') === $date_str) {
        $date_written = $date_obj->format("F j, Y");
    } else {
        $date_written = date("F j, Y"); 
    }

    if (!isset($_GET['id'])) {
        if(isset($_GET['payee']) || isset($_GET['amt']) || isset($_GET['memo']) || isset($_GET['date'])){
            $amount_text = numberToWords($amount) . " and " . sprintf("%02d", ($amount - floor($amount)) * 100) . "/100";
            $checks_data = [
                [
                    'amount' => $amount,
                    'memo_1' => $memo,
                    'date_written' => $date_written,
                    'friendly_name' => $payee,
                ],
            ];
        }
        else{
            die("Invalid check ID(s)");
        }
        
    }
    else{

        if (!empty($check_ids)) {
            $idList = implode(',', $check_ids);
            $update_query = "UPDATE checks SET times_printed = times_printed + 1 WHERE check_id IN ($idList)";
            $conn->query($update_query);
            if ($conn->error) {
            }

            $query = "UPDATE checks 
                        SET times_printed = times_printed + 1
                        WHERE check_id IN ($idList)
                        AND times_printed = times_printed; -- Prevents error if no rows matched

                        SELECT c.amount, c.memo_1, c.date_written, p.friendly_name, c.check_id, c.times_printed
                        FROM checks c
                        JOIN payees p ON c.payee_id = p.payee_id
                        WHERE c.check_id IN ($idList)";

            if ($conn->multi_query($query)) {
                $update_result = $conn->store_result();
                if ($update_result) {
                    mysqli_free_result($update_result); 
                }

                if ($conn->next_result()) {
                    $result = $conn->store_result();
                    if ($result) {
                        $checks_data = $result->fetch_all(MYSQLI_ASSOC);
                        mysqli_free_result($result);
                    }
                }
            }  else {
                die("Multi-query failed: " . $conn->error);
            }
            
        }
    }
    
    $conn->close();
} catch (mysqli_sql_exception $e) {
    die("Database error: " . $e->getMessage());
}
?>
<!DOCTYPE html>
<html>

<head>
    <title>Print Check</title>
    <style>
        .print-text {
            text-transform: uppercase;
            font-family: Verdana;
            font-size: 14px;
        }

        @media print {
            @page {
                size: 8.5in 11in;
                margin: 0;
            }

            body {
                width: 8.5in;
                height: auto;
                margin: 0;
            }

            .print-text {
                position: absolute;
                font-size: 12px;
            }

            #print-payee {
                left: 1.175in;
                top: 1.55in;
            }

            #print-amount-text {
                top: 1.05in;
                max-width: 3.5in;
                left: 1.175in;
            }

            #print-memo {
                top: 2.43in;
                left: 1.175in;
            }

            #print-date {
                top: 1.55in;
                left: 5.225in;
            }

            #print-amount {
                top: 1.55in;
                left: 7.1in;
            }

            .print-check {
                page-break-after: always;
                position: relative;
                width: 8.5in;
                height: 3.5in;
                margin: 0 0 0.5in 0;
                padding: 0;
                overflow: visible;
                display: block;
            }

            .amount {
                position: absolute;
                top: 1.2in;
                left: 6.5in;
                font-size: 14pt;
            }

            .date {
                position: absolute;
                top: 0.5in;
                left: 6.5in;
                font-size: 12pt;
            }

            .memo {
                position: absolute;
                bottom: 0.3in;
                left: 1in;
                font-size: 12pt;
            }
        }

        .print-check {
            position: relative;
            width: 8.5in;
            height: 3.5in;
            margin-bottom: 0.5in;
        }

        .amount {
            position: absolute;
            top: 1.2in;
            left: 6.5in;
            font-size: 14pt;
        }

        .date {
            position: absolute;
            top: 0.5in;
            left: 6.5in;
            font-size: 12pt;
        }

        .memo {
            position: absolute;
            bottom: 0.3in;
            left: 1in;
            font-size: 12pt;
        }
    </style>
</head>

<body onload="window.print();">
    <?php foreach ($checks_data as $check) : ?>
        <?php
        $amount = formatAmount($check['amount']);
        $whole_number = floor($check['amount']);
        $cents = round(($check['amount'] - $whole_number) * 100);
        $amount_words = numberToWords($whole_number) . " and " . sprintf("%02d", $cents) . "/100";
        $memo = htmlspecialchars($check['memo_1']);
        $payee_name = htmlspecialchars($check['friendly_name']);
        
        if(isset($_GET['id'])){
            $date_written = date("F j, Y", strtotime($check['date_written']));
        }
        else{
            $date_written = $date_written;
        }
        ?>
        <div class="print-check">
            <p class="print-text" id="print-date"><?php echo $date_written; ?></p>
            <p class="print-text" id="print-payee"><?php echo $payee_name; ?></p>
            <p class="print-text" id="print-amount"><?php echo $amount; ?></p>
            <p class="print-text" id="print-amount-text"><?php echo $amount_words; ?></span>
            <p class="print-text" id="print-memo"><?php echo $memo; ?></p>
        </div>
    <?php endforeach; ?>
</body>

</html>